package com.ruoyi.system.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.BNetHistory;
import com.ruoyi.system.service.IBNetHistoryService;
import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 连网历史Controller
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@RestController
@RequestMapping("/netEwm/netHistory")
@Api(tags = "连网历史")
@Transactional(rollbackFor = Exception.class)
public class BNetHistoryController extends BaseController {
    @Resource
    private IBNetHistoryService bNetHistoryService;

    /**
     * 查询连网历史列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:list')")
    @GetMapping("/list")
    public TableDataInfo list(BNetHistory bNetHistory) {
        startPage();
        List<BNetHistory> list = bNetHistoryService.selectBNetHistoryList(bNetHistory);
        return getDataTable(list);
    }

    /**
     * 导出连网历史列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:export')")
    @Log(title = "连网历史", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BNetHistory bNetHistory) {
        List<BNetHistory> list = bNetHistoryService.selectBNetHistoryList(bNetHistory);
        ExcelUtil<BNetHistory> util = new ExcelUtil<BNetHistory>(BNetHistory.class);
        util.exportExcel(response, list, "连网历史数据");
    }

    /**
     * 获取连网历史详细信息
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bNetHistoryService.selectBNetHistoryById(id));
    }

    /**
     * 新增连网历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:add')")
    @Log(title = "连网历史", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BNetHistory bNetHistory) {
        return toAjax(bNetHistoryService.insertBNetHistory(bNetHistory));
    }

    /**
     * 修改连网历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:edit')")
    @Log(title = "连网历史", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BNetHistory bNetHistory) {
        return toAjax(bNetHistoryService.updateBNetHistory(bNetHistory));
    }

    /**
     * 删除连网历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:netHistory:remove')")
    @Log(title = "连网历史", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bNetHistoryService.deleteBNetHistoryByIds(ids));
    }
}
