package com.ruoyi.system.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.BPoster;
import com.ruoyi.system.domain.dto.request.PosterRequest;
import com.ruoyi.system.service.IBPosterService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * 广告Controller
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@RestController
@RequestMapping("/netEwm/poster")
@Api(tags = "广告")
@Transactional(rollbackFor = Exception.class)
public class BPosterController extends BaseController {
    @Resource
    private IBPosterService bPosterService;

    /**
     * 查询广告列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:list')")
    @GetMapping("/list")
    public TableDataInfo list(BPoster bPoster) {
        startPage();
        List<BPoster> list = bPosterService.selectBPosterList(bPoster);
        return getDataTable(list);
    }

    /**
     * 导出广告列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:export')")
    @Log(title = "广告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BPoster bPoster) {
        List<BPoster> list = bPosterService.selectBPosterList(bPoster);
        ExcelUtil<BPoster> util = new ExcelUtil<BPoster>(BPoster.class);
        util.exportExcel(response, list, "广告数据");
    }

    /**
     * 获取广告详细信息
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bPosterService.selectBPosterById(id));
    }

    /**
     * 新增广告
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:add')")
    @Log(title = "广告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BPoster bPoster) {
        return toAjax(bPosterService.insertBPoster(bPoster));
    }

    /**
     * 广告批量分配商户
     *
     * @param req 请求类
     * @return 响应类
     */
    @PostMapping("batchAllocation")
    @ApiOperation("广告批量分配商户")
    public AjaxResult batchAllocation(@Valid @RequestBody PosterRequest req) {
        bPosterService.batchAllocation(req);
        return success();
    }

    /**
     * 修改广告
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:edit')")
    @Log(title = "广告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BPoster bPoster) {
        return toAjax(bPosterService.updateBPoster(bPoster));
    }

    /**
     * 删除广告
     */
    @PreAuthorize("@ss.hasPermi('netEwm:poster:remove')")
    @Log(title = "广告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bPosterService.deleteBPosterByIds(ids));
    }
}
