package com.ruoyi.system.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.BPosterHistory;
import com.ruoyi.system.service.IBPosterHistoryService;
import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 广告历史Controller
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@RestController
@Api(tags = "广告历史")
@Transactional(rollbackFor = Exception.class)
@RequestMapping("/netEwm/posterHistory")
public class BPosterHistoryController extends BaseController {
    @Resource
    private IBPosterHistoryService bPosterHistoryService;

    /**
     * 查询广告历史列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:list')")
    @GetMapping("/list")
    public TableDataInfo list(BPosterHistory bPosterHistory) {
        startPage();
        List<BPosterHistory> list = bPosterHistoryService.selectBPosterHistoryList(bPosterHistory);
        return getDataTable(list);
    }

    /**
     * 导出广告历史列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:export')")
    @Log(title = "广告历史", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BPosterHistory bPosterHistory) {
        List<BPosterHistory> list = bPosterHistoryService.selectBPosterHistoryList(bPosterHistory);
        ExcelUtil<BPosterHistory> util = new ExcelUtil<BPosterHistory>(BPosterHistory.class);
        util.exportExcel(response, list, "广告历史数据");
    }

    /**
     * 获取广告历史详细信息
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bPosterHistoryService.selectBPosterHistoryById(id));
    }

    /**
     * 新增广告历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:add')")
    @Log(title = "广告历史", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BPosterHistory bPosterHistory) {
        return toAjax(bPosterHistoryService.insertBPosterHistory(bPosterHistory));
    }

    /**
     * 修改广告历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:edit')")
    @Log(title = "广告历史", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BPosterHistory bPosterHistory) {
        return toAjax(bPosterHistoryService.updateBPosterHistory(bPosterHistory));
    }

    /**
     * 删除广告历史
     */
    @PreAuthorize("@ss.hasPermi('netEwm:posterHistory:remove')")
    @Log(title = "广告历史", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bPosterHistoryService.deleteBPosterHistoryByIds(ids));
    }
}
