package com.ruoyi.system.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.BShanghu;
import com.ruoyi.system.service.IBShanghuService;
import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商户Controller
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@RestController
@Api(tags = "商户")
@Transactional(rollbackFor = Exception.class)
@RequestMapping("/netEwm/shanghu")
public class BShanghuController extends BaseController {
    @Resource
    private IBShanghuService bShanghuService;

    /**
     * 查询商户列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:list')")
    @GetMapping("/list")
    public TableDataInfo list(BShanghu bShanghu) {
        startPage();
        List<BShanghu> list = bShanghuService.selectBShanghuList(bShanghu);
        return getDataTable(list);
    }

    /**
     * 导出商户列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:export')")
    @Log(title = "商户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BShanghu bShanghu) {
        List<BShanghu> list = bShanghuService.selectBShanghuList(bShanghu);
        ExcelUtil<BShanghu> util = new ExcelUtil<BShanghu>(BShanghu.class);
        util.exportExcel(response, list, "商户数据");
    }

    /**
     * 获取商户详细信息
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bShanghuService.selectBShanghuById(id));
    }

    /**
     * 新增商户
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:add')")
    @Log(title = "商户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BShanghu bShanghu) {
        return toAjax(bShanghuService.insertBShanghu(bShanghu));
    }

    /**
     * 修改商户
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:edit')")
    @Log(title = "商户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BShanghu bShanghu) {
        return toAjax(bShanghuService.updateBShanghu(bShanghu));
    }

    /**
     * 删除商户
     */
    @PreAuthorize("@ss.hasPermi('netEwm:shanghu:remove')")
    @Log(title = "商户", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bShanghuService.deleteBShanghuByIds(ids));
    }
}
