package com.ruoyi.system.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.dto.request.WeChatCodeRequest;
import com.ruoyi.system.domain.dto.request.WeChatRequest;
import com.ruoyi.system.service.WeChatService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 微信签名
 *
 * @Author: wu
 * @DateTime: 2023/4/25 9:14
 */
@Api(tags = "微信签名")
@RestController
@RequestMapping("/shian/wechat")
@Transactional(rollbackFor = Exception.class)
public class WeChatController extends BaseController {

    @Resource
    private WeChatService weChatService;


    /**
     * 获取微信accessToken
     *
     * @return accessToken
     */
    @ApiOperation("获取微信accessToken")
    @GetMapping("/findAccessToken")
    public AjaxResult findAccessToken() {

        return AjaxResult.success(weChatService.findAccessToken());
    }

    /**
     * 获取微信二维码
     *
     * @param req 获取小程序码请求类
     * @return 微信二维码二进制
     */
    @ApiOperation("获取微信二维码")
    @PostMapping("/findWxCode")
    public AjaxResult findWxCode(@RequestBody WeChatCodeRequest req) {

        return AjaxResult.success(weChatService.findWxCode(req));
    }

    /**
     * 获取微信手机号
     *
     * @param code 手机号获取凭证
     * @return 手机号
     */
    @ApiOperation("获取微信手机号")
    @GetMapping("/getUserPhoneNumber")
    public AjaxResult getUserPhoneNumber(String code) {

        return AjaxResult.success(weChatService.getUserPhoneNumber(code));
    }

    /**
     * 获取微信jsapiTicket
     *
     * @return jsapiTicket
     */
    @ApiOperation("获取微信jsapiTicket")
    @GetMapping("/findJsapiTicket")
    public AjaxResult findJsapiTicket() {

        return AjaxResult.success(weChatService.findJsapiTicket());
    }

    /**
     * 微信获取签名
     *
     * @param req 请求类
     * @return 微信签名
     */
    @ApiOperation("微信获取签名")
    @GetMapping("/findSignature")
    public AjaxResult findSignature(@Validated WeChatRequest req) {

        return AjaxResult.success(weChatService.findSignature(req));
    }
}