package com.ruoyi.system.domain.dto.request;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;

/**
 * 获取小程序码请求类
 *
 * @author wu
 * @since 2023/11/27 15:19
 */
@Data
@ApiModel(value = "获取小程序码请求类")
public class WeChatCodeRequest implements Serializable {
    private static final long serialVersionUID = 8837329526135742856L;

    /**
     * 扫码进入的小程序页面路径，最大长度 1024 个字符，不能为空，scancode_time为系统保留参数，不允许配置；
     * 对于小游戏，可以只传入 query 部分，来实现传参效果，
     * 如：传入 "?foo=bar"，即可在 wx.getLaunchOptionsSync 接口中的 query 参数
     * 获取到 {foo:"bar"}。
     */
    @ApiModelProperty(value = "扫码进入的小程序页面路径，最大长度 1024 个字符，不能为空，" +
            "scancode_time为系统保留参数，不允许配置；对于小游戏，可以只传入 query 部分，" +
            "来实现传参效果，如：传入 \"?foo=bar\"，即可在 wx.getLaunchOptionsSync " +
            "接口中的 query 参数获取到 {foo:\"bar\"}。", required = true)
    @NotBlank(message = "小程序页面路径不能为空")
    private String path;

    /**
     * 二维码的宽度，单位 px。默认值为430，最小 280px，最大 1280px
     */
    @ApiModelProperty(value = "二维码的宽度，单位 px。默认值为430，最小 280px，最大 1280px")
    private Integer width;

    /**
     * 商户id
     */
    @ApiModelProperty(value = "商户id", required = true)
    @NotNull(message = "商户id不能为空")
    private Long shanghuId;
}
