package com.ruoyi.system.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BNet;
import com.ruoyi.system.mapper.BNetMapper;
import com.ruoyi.system.service.IBNetService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 网络Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@Service
public class BNetServiceImpl implements IBNetService {

    @Resource
    private BNetMapper bNetMapper;

    /**
     * 查询网络
     *
     * @param id 网络主键
     * @return 网络
     */
    @Override
    public BNet selectBNetById(Long id) {
        return bNetMapper.selectBNetById(id);
    }

    /**
     * 查询网络列表
     *
     * @param bNet 网络
     * @return 网络
     */
    @Override
    public List<BNet> selectBNetList(BNet bNet) {
        return bNetMapper.selectBNetList(bNet);
    }

    /**
     * 新增网络
     *
     * @param bNet 网络
     * @return 结果
     */
    @Override
    public int insertBNet(BNet bNet) {
        if (bNet.getShanghuId() == null) {
            throw new ServiceException("商户id不能为空");
        }
        BNet net = bNetMapper.findByShanghuId(bNet.getShanghuId());
        if (BeanUtil.isNotEmpty(net)) {
            throw new ServiceException("已经存在wifi网络不能新增");
        }
        bNet.setCreateTime(DateUtils.getNowDate());
        return bNetMapper.insertBNet(bNet);
    }

    /**
     * 修改网络
     *
     * @param bNet 网络
     * @return 结果
     */
    @Override
    public int updateBNet(BNet bNet) {
        bNet.setUpdateTime(DateUtils.getNowDate());
        return bNetMapper.updateBNet(bNet);
    }

    /**
     * 批量删除网络
     *
     * @param ids 需要删除的网络主键
     * @return 结果
     */
    @Override
    public int deleteBNetByIds(Long[] ids) {
        return bNetMapper.deleteBNetByIds(ids);
    }

    /**
     * 删除网络信息
     *
     * @param id 网络主键
     * @return 结果
     */
    @Override
    public int deleteBNetById(Long id) {
        return bNetMapper.deleteBNetById(id);
    }

    /**
     * 根据商户id删除wifi
     *
     * @param id 商户id
     */
    @Override
    public void deleteBNetByShangHuId(Long id) {
        bNetMapper.deleteBNetByShangHuId(id);
    }

    /**
     * 根据商户id查询wifi(提供二维码接口)
     *
     * @param id 商户id
     * @return wifi信息
     */
    @Override
    public BNet findById(Long id) {
        return bNetMapper.findByShanghuId(id);
    }
}
