package com.ruoyi.system.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BPoster;
import com.ruoyi.system.domain.dto.request.PosterRequest;
import com.ruoyi.system.mapper.BPosterMapper;
import com.ruoyi.system.service.IBPosterService;
import com.ruoyi.system.service.IBShanghuService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 广告Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@Service
public class BPosterServiceImpl implements IBPosterService {

    @Resource
    private BPosterMapper bPosterMapper;

    @Resource
    private IBShanghuService shanghuService;

    /**
     * 查询广告
     *
     * @param id 广告主键
     * @return 广告
     */
    @Override
    public BPoster selectBPosterById(Long id) {
        BPoster bPoster = bPosterMapper.selectBPosterById(id);
        // 查询广告关联的商户id
        if (BeanUtil.isNotEmpty(bPoster)) {
            List<Long> shanghuIdList = shanghuService.findIdByPosterId(bPoster.getId());
            bPoster.setShanghuIdList(shanghuIdList);
        }
        return bPoster;
    }

    /**
     * 查询广告列表
     *
     * @param bPoster 广告
     * @return 广告
     */
    @Override
    public List<BPoster> selectBPosterList(BPoster bPoster) {
        return bPosterMapper.selectBPosterList(bPoster);
    }

    /**
     * 新增广告
     *
     * @param bPoster 广告
     * @return 结果
     */
    @Override
    public int insertBPoster(BPoster bPoster) {
        bPoster.setCreateTime(DateUtils.getNowDate());
        return bPosterMapper.insertBPoster(bPoster);
    }

    /**
     * 修改广告
     *
     * @param bPoster 广告
     * @return 结果
     */
    @Override
    public int updateBPoster(BPoster bPoster) {
        bPoster.setUpdateTime(DateUtils.getNowDate());
        return bPosterMapper.updateBPoster(bPoster);
    }

    /**
     * 批量删除广告
     *
     * @param ids 需要删除的广告主键
     * @return 结果
     */
    @Override
    public int deleteBPosterByIds(Long[] ids) {
        return bPosterMapper.deleteBPosterByIds(ids);
    }

    /**
     * 删除广告信息
     *
     * @param id 广告主键
     * @return 结果
     */
    @Override
    public int deleteBPosterById(Long id) {
        return bPosterMapper.deleteBPosterById(id);
    }

    /**
     * 广告批量分配商户
     *
     * @param req 请求类
     */
    @Override
    public void batchAllocation(PosterRequest req) {
        BPoster bPoster = bPosterMapper.selectBPosterById(req.getPosterId());
        if (BeanUtil.isEmpty(bPoster)) {
            throw new ServiceException("所选广告不存在");
        }
        if (CollectionUtil.isNotEmpty(req.getShanghuIds())) {
            shanghuService.editPostIdByIds(req.getPosterId(), req.getShanghuIds());
            return;
        }
        if (StrUtil.isNotEmpty(req.getShanghuCity()) || StrUtil.isNotEmpty(req.getShanghuName())) {
            shanghuService.editPostIdByReq(req.getPosterId(), req.getShanghuCity(), req.getShanghuName());
            return;
        }
        throw new ServiceException("参数错误");

    }
}
