package com.ruoyi.system.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.BPoster;
import com.ruoyi.system.domain.BShanghu;
import com.ruoyi.system.mapper.BShanghuMapper;
import com.ruoyi.system.service.IBNetService;
import com.ruoyi.system.service.IBPosterService;
import com.ruoyi.system.service.IBShanghuService;
import com.ruoyi.system.service.ISysUserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 商户Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-21
 */
@Service
public class BShanghuServiceImpl implements IBShanghuService {

    @Resource
    private BShanghuMapper bShanghuMapper;

    @Resource
    private ISysUserService userService;

    @Resource
    private IBPosterService posterService;

    @Resource
    private IBNetService netService;

    /**
     * 查询商户
     *
     * @param id 商户主键
     * @return 商户
     */
    @Override
    public BShanghu selectBShanghuById(Long id) {
        return bShanghuMapper.selectBShanghuById(id);
    }

    /**
     * 查询商户列表
     *
     * @param bShanghu 商户
     * @return 商户
     */
    @Override
    public List<BShanghu> selectBShanghuList(BShanghu bShanghu) {
        return bShanghuMapper.selectBShanghuList(bShanghu);
    }

    /**
     * 新增商户
     *
     * @param bShanghu 商户
     * @return 结果
     */
    @Override
    public int insertBShanghu(BShanghu bShanghu) {
        bShanghu.setCreateTime(DateUtils.getNowDate());
        SysUser user = new SysUser();
        user.setUserName(bShanghu.getPhoneNumber());
        user.setPassword(SecurityUtils.encryptPassword("123456"));
        user.setNickName(bShanghu.getLinkMan());
        // 注册用户
        if (!userService.checkUserNameUnique(user)) {
            throw new ServiceException("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
        }
        Long[] roleIds = new Long[1];
        roleIds[0] = 2L;
        user.setRoleIds(roleIds);
        userService.insertUser(user);
        return bShanghuMapper.insertBShanghu(bShanghu);
    }

    /**
     * 修改商户
     *
     * @param bShanghu 商户
     * @return 结果
     */
    @Override
    public int updateBShanghu(BShanghu bShanghu) {
        if (bShanghu.getPosterId() != null) {
            BPoster bPoster = posterService.selectBPosterById(bShanghu.getPosterId());
            if (BeanUtil.isEmpty(bPoster)) {
                throw new ServiceException("所选广告不存在");
            }
        }
        bShanghu.setUpdateTime(DateUtils.getNowDate());
        return bShanghuMapper.updateBShanghu(bShanghu);
    }

    /**
     * 批量删除商户
     *
     * @param ids 需要删除的商户主键
     * @return 结果
     */
    @Override
    public int deleteBShanghuByIds(Long[] ids) {
        return bShanghuMapper.deleteBShanghuByIds(ids);
    }

    /**
     * 删除商户信息
     *
     * @param id 商户主键
     * @return 结果
     */
    @Override
    public int deleteBShanghuById(Long id) {
        // 删除商户wifi
        netService.deleteBNetByShangHuId(id);
        return bShanghuMapper.deleteBShanghuById(id);
    }

    /**
     * 为商户批量填充广告
     *
     * @param posterId   广告id
     * @param shanghuIds 商户id集合
     */
    @Override
    public void editPostIdByIds(Long posterId, List<Long> shanghuIds) {
        bShanghuMapper.editPostIdByIds(posterId, shanghuIds);
    }

    /**
     * 为商户批量填充广告
     *
     * @param posterId    广告id
     * @param shanghuCity 商户城市
     * @param shanghuName 商户名称
     */
    @Override
    public void editPostIdByReq(Long posterId, String shanghuCity, String shanghuName) {
        bShanghuMapper.editPostIdByReq(posterId, shanghuCity, shanghuName);
    }

    /**
     * 根据广告id查询商户id集合
     *
     * @param id 广告id
     * @return 商户id集合
     */
    @Override
    public List<Long> findIdByPosterId(Long id) {
        return bShanghuMapper.findIdByPosterId(id);
    }

    /**
     * 根据手机号查询商户
     *
     * @param phoneNumber 手机号
     * @return 商户信息
     */
    @Override
    public BShanghu findByPhone(String phoneNumber) {
        return bShanghuMapper.findByPhone(phoneNumber);
    }
}
